@@ -64,10 +64,16 @@ sub repo_info {
     return $ret->{repository};
 }
 
+sub repo_create {
+    my ($class,%args) = @_;
+    my $ret = $class->request( qq{repos/create} , %args );
+    return $ret->{repository};
+}
 
 sub user_info {
     my ($class,$user) = @_;
-    return $class->request( qq{repos/show/$user} );
+    my $ret =  $class->request( qq{repos/show/$user} );
+    return $ret;
 }
 
 sub user_repos {
@@ -77,6 +83,7 @@ sub user_repos {
 }
 
 
+
 1;
 __END__
 =head1 NAME
@@ -101,6 +108,15 @@ Show repository networks of [user]'s [repo].
 
 Show user info
 
+=head2 repo_create( [Hash] args )
+
+args:
+
+    name =>
+    description =>
+    homepage => 
+    public => 1 for public , 0 for private.
+
 =head2 repo_info( [Str] user, [Str] repo)
 
 Which returnes a hashref:
